title: Welcome!
created: 2010/10/10 00:00:00
tags: unsorted

New [public-static](http://publicstatic.org) website was created. And this is a first blog post to demonstrate how everything works.

Directory structure:

* `assets` — static web site assets including stylesheets, javascript and assets images.
* `pages` — markdown-formatted web pages.
* `posts`
* `prototypes` — content prototypes for various page types. E.g. `post.md` file is a prototype for new blog posts. It will be cloned while creating each new post.
* `templates` — web page templates.

Useful links:

* [Documentation](https://github.com/dreikanter/public-static/blob/master/README.md)
* [Homepage](http://github.com/dreikanter/public-static) at GitHub
